"use strict";
exports.__esModule = true;
exports.sortFiles = exports.getCodeAnswerFile = exports.getCodeFiles = exports.getLessonProps = exports.getChapterProps = exports.getChapters = exports.getLessons = exports.queryFiles = void 0;
var fs_1 = require("fs");
var path_1 = require("path");
var gray_matter_1 = require("gray-matter");
var constants_1 = require("./constants");
var queryFiles = function (_a) {
    var _path = _a._path, regex = _a.regex;
    return fs_1["default"].readdirSync("".concat(constants_1.ROOT_PATH, "/").concat(_path)).filter(function (file) {
        return path_1["default"].basename(file).match(regex);
    });
};
exports.queryFiles = queryFiles;
var getLessons = function () {
    return (0, exports.queryFiles)({ _path: ".", regex: "lesson" }).map(function (file) {
        return {
            id: parseInt(path_1["default"].basename(file).split("-")[1])
        };
    });
};
exports.getLessons = getLessons;
var getChapters = function (lessonId) {
    return (0, exports.queryFiles)({ _path: "lesson-".concat(lessonId, "/"), regex: "chapter" }).map(function (file) {
        return {
            id: parseInt(path_1["default"].basename(file).split("-")[1])
        };
    });
};
exports.getChapters = getChapters;
var getChapterProps = function (lessonId) {
    var chapters = (0, exports.getChapters)(parseInt(lessonId));
    var firstChapter = chapters[0] || null;
    return {
        firstChapter: firstChapter
    };
};
exports.getChapterProps = getChapterProps;
var getLessonProps = function (lessonId) {
    var lessons = (0, exports.getLessons)();
    var lessonIndex = lessons.findIndex(function (l) { return l.id === parseInt(lessonId); });
    var isLastLesson = lessonIndex === lessons.length - 1;
    var nextLesson = isLastLesson ? null : lessons[lessonIndex + 1];
    return {
        nextLesson: nextLesson,
        isLastLesson: isLastLesson
    };
};
exports.getLessonProps = getLessonProps;
var getCodeFiles = function (lessonId, chapterId) {
    var _path = "lesson-".concat(lessonId, "/chapter-").concat(chapterId, "/");
    return (0, exports.queryFiles)({
        _path: _path,
        regex: "^((?!answer|md).)*$"
    }).map(function (file) {
        var postContent = fs_1["default"].readFileSync("".concat(constants_1.ROOT_PATH, "/").concat(_path).concat(file), "utf8");
        var body = (0, gray_matter_1["default"])(postContent).content;
        return {
            fileName: path_1["default"].basename(file),
            body: body
        };
    });
};
exports.getCodeFiles = getCodeFiles;
var getCodeAnswerFile = function (lessonId, chapterId) {
    var _path = "lesson-".concat(lessonId, "/chapter-").concat(chapterId, "/");
    var files = (0, exports.queryFiles)({
        _path: _path,
        regex: "answer"
    }).map(function (file) {
        var postContent = fs_1["default"].readFileSync("".concat(constants_1.ROOT_PATH, "/").concat(_path).concat(file), "utf8");
        var body = (0, gray_matter_1["default"])(postContent).content;
        return {
            fileName: path_1["default"].basename(file),
            body: body
        };
    });
    return (files === null || files === void 0 ? void 0 : files[0]) || null;
};
exports.getCodeAnswerFile = getCodeAnswerFile;
var sortFiles = function (files, fileNameToEdit) {
    return files.sort(function (a, b) {
        if (fileNameToEdit && a.fileName === fileNameToEdit) {
            return -1;
        }
        else
            return 1;
    });
};
exports.sortFiles = sortFiles;
